/*
 * Copyright (c) 2009 Lukas Mejdrech
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup packet
 *  @{
 */

/** @file
 *  Packet server.
 *  The hosting module has to be compiled with both the packet.c and the packet_server.c source files.
 *  To function correctly, initialization of the packet map by the pm_init() function has to happen at the first place.
 *  Then the packet messages have to be processed by the packet_server_message() function.
 *  The packet map should be released by the pm_destroy() function during the module termination.
 *  @see IS_NET_PACKET_MESSAGE()
 */

#ifndef __NET_PACKET_SERVER_H__
#define __NET_PACKET_SERVER_H__

#include <ipc/ipc.h>

/** Processes the packet server message.
 *  @param callid The message identifier. Input parameter.
 *  @param call The message parameters. Input parameter.
 *  @param answer The message answer parameters. Output parameter.
 *  @param answer_count The last parameter for the actual answer in the answer parameter. Output parameter.
 *  \todo all possible message returns?
 *  @returns EOK on success.
 *  @returns ENOTSUP if the message is not known.
 */
int	packet_server_message( ipc_callid_t callid, ipc_call_t * call, ipc_call_t * answer, int * answer_count );

#endif

/** @}
 */
